==> ask-smapi-model-1.2.0.tar.gz: ask-smapi-model-1.2.0/ask_smapi_model/v1/skill/manifest/display_interface.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum
from ask_smapi_model.v1.skill.manifest.interface import Interface


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime
    from ask_smapi_model.v1.skill.manifest.display_interface_apml_version import DisplayInterfaceApmlVersionV1
    from ask_smapi_model.v1.skill.manifest.display_interface_template_version import DisplayInterfaceTemplateVersionV1


class DisplayInterface(Interface):
    """
    Used to declare that the skill uses the Display interface. When a skill declares that it uses the Display interface the Display interface will be passed in the supportedInterfaces section of devices which meet any of the required minimum version attributes specified in the manifest. If the device does not meet any of the minimum versions specified in the manifest the Display interface will not be present in the supportedInterfaces section. If neither the minimumTemplateVersion nor the minimumApmlVersion attributes are specified in the manifes then the minimumTemplateVersion is defaulted to 1.0 and apmlVersion is omitted.


    :param minimum_template_version: 
    :type minimum_template_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_template_version.DisplayInterfaceTemplateVersion
    :param minimum_apml_version: 
    :type minimum_apml_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_apml_version.DisplayInterfaceApmlVersion

    """
    deserialized_types = {
        'object_type': 'str',
        'minimum_template_version': 'ask_smapi_model.v1.skill.manifest.display_interface_template_version.DisplayInterfaceTemplateVersion',
        'minimum_apml_version': 'ask_smapi_model.v1.skill.manifest.display_interface_apml_version.DisplayInterfaceApmlVersion'
    }  # type: Dict

    attribute_map = {
        'object_type': 'type',
        'minimum_template_version': 'minimumTemplateVersion',
        'minimum_apml_version': 'minimumApmlVersion'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, minimum_template_version=None, minimum_apml_version=None):
        # type: (Optional[DisplayInterfaceTemplateVersionV1], Optional[DisplayInterfaceApmlVersionV1]) -> None
        """Used to declare that the skill uses the Display interface. When a skill declares that it uses the Display interface the Display interface will be passed in the supportedInterfaces section of devices which meet any of the required minimum version attributes specified in the manifest. If the device does not meet any of the minimum versions specified in the manifest the Display interface will not be present in the supportedInterfaces section. If neither the minimumTemplateVersion nor the minimumApmlVersion attributes are specified in the manifes then the minimumTemplateVersion is defaulted to 1.0 and apmlVersion is omitted.

        :param minimum_template_version: 
        :type minimum_template_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_template_version.DisplayInterfaceTemplateVersion
        :param minimum_apml_version: 
        :type minimum_apml_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_apml_version.DisplayInterfaceApmlVersion
        """
        self.__discriminator_value = "RENDER_TEMPLATE"  # type: str

        self.object_type = self.__discriminator_value
        super(DisplayInterface, self).__init__(object_type=self.__discriminator_value)
        self.minimum_template_version = minimum_template_version
        self.minimum_apml_version = minimum_apml_version

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, DisplayInterface):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask-smapi-model-1.8.2.tar.gz: ask-smapi-model-1.8.2/ask_smapi_model/v1/skill/manifest/display_interface.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum
from ask_smapi_model.v1.skill.manifest.interface import Interface


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime
    from ask_smapi_model.v1.skill.manifest.display_interface_apml_version import DisplayInterfaceApmlVersion as Manifest_DisplayInterfaceApmlVersionV1
    from ask_smapi_model.v1.skill.manifest.display_interface_template_version import DisplayInterfaceTemplateVersion as Manifest_DisplayInterfaceTemplateVersionV1


class DisplayInterface(Interface):
    """
    Used to declare that the skill uses the Display interface. When a skill declares that it uses the Display interface the Display interface will be passed in the supportedInterfaces section of devices which meet any of the required minimum version attributes specified in the manifest. If the device does not meet any of the minimum versions specified in the manifest the Display interface will not be present in the supportedInterfaces section. If neither the minimumTemplateVersion nor the minimumApmlVersion attributes are specified in the manifes then the minimumTemplateVersion is defaulted to 1.0 and apmlVersion is omitted.


    :param minimum_template_version: 
    :type minimum_template_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_template_version.DisplayInterfaceTemplateVersion
    :param minimum_apml_version: 
    :type minimum_apml_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_apml_version.DisplayInterfaceApmlVersion

    """
    deserialized_types = {
        'object_type': 'str',
        'minimum_template_version': 'ask_smapi_model.v1.skill.manifest.display_interface_template_version.DisplayInterfaceTemplateVersion',
        'minimum_apml_version': 'ask_smapi_model.v1.skill.manifest.display_interface_apml_version.DisplayInterfaceApmlVersion'
    }  # type: Dict

    attribute_map = {
        'object_type': 'type',
        'minimum_template_version': 'minimumTemplateVersion',
        'minimum_apml_version': 'minimumApmlVersion'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, minimum_template_version=None, minimum_apml_version=None):
        # type: (Optional[Manifest_DisplayInterfaceTemplateVersionV1], Optional[Manifest_DisplayInterfaceApmlVersionV1]) -> None
        """Used to declare that the skill uses the Display interface. When a skill declares that it uses the Display interface the Display interface will be passed in the supportedInterfaces section of devices which meet any of the required minimum version attributes specified in the manifest. If the device does not meet any of the minimum versions specified in the manifest the Display interface will not be present in the supportedInterfaces section. If neither the minimumTemplateVersion nor the minimumApmlVersion attributes are specified in the manifes then the minimumTemplateVersion is defaulted to 1.0 and apmlVersion is omitted.

        :param minimum_template_version: 
        :type minimum_template_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_template_version.DisplayInterfaceTemplateVersion
        :param minimum_apml_version: 
        :type minimum_apml_version: (optional) ask_smapi_model.v1.skill.manifest.display_interface_apml_version.DisplayInterfaceApmlVersion
        """
        self.__discriminator_value = "RENDER_TEMPLATE"  # type: str

        self.object_type = self.__discriminator_value
        super(DisplayInterface, self).__init__(object_type=self.__discriminator_value)
        self.minimum_template_version = minimum_template_version
        self.minimum_apml_version = minimum_apml_version

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, DisplayInterface):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
